@@ -6,7 +6,7 @@ import (
 	"regexp"
 	"strings"
 
-	iov1 "github.com/openshift/cluster-ingress-operator/pkg/api/v1"
+	iov1 "github.com/openshift/api/operatoringress/v1"
 	logf "github.com/openshift/cluster-ingress-operator/pkg/log"
 	"github.com/openshift/cluster-ingress-operator/pkg/manifests"
 	retryable "github.com/openshift/cluster-ingress-operator/pkg/util/retryableerror"
@@ -39,6 +39,12 @@ const (
 	controllerName = "ingress_controller"
 )
 
+// TODO: consider moving these to openshift/api
+const (
+	IngressControllerAdmittedConditionType           = "Admitted"
+	IngressControllerDeploymentDegradedConditionType = "DeploymentDegraded"
+)
+
 var (
 	log = logf.Logger.WithName(controllerName)
 	// tlsVersion13Ciphers is a list of TLS v1.3 cipher suites as specified by
@@ -227,7 +233,7 @@ func (r *reconciler) admit(current *operatorv1.IngressController, ingressConfig
 		switch err := err.(type) {
 		case *admissionRejection:
 			updated.Status.Conditions = mergeConditions(updated.Status.Conditions, operatorv1.OperatorCondition{
-				Type:    iov1.IngressControllerAdmittedConditionType,
+				Type:    IngressControllerAdmittedConditionType,
 				Status:  operatorv1.ConditionFalse,
 				Reason:  "Invalid",
 				Message: err.Reason,
@@ -243,7 +249,7 @@ func (r *reconciler) admit(current *operatorv1.IngressController, ingressConfig
 	}
 
 	updated.Status.Conditions = mergeConditions(updated.Status.Conditions, operatorv1.OperatorCondition{
-		Type:   iov1.IngressControllerAdmittedConditionType,
+		Type:   IngressControllerAdmittedConditionType,
 		Status: operatorv1.ConditionTrue,
 		Reason: "Valid",
 	})
@@ -258,7 +264,7 @@ func (r *reconciler) admit(current *operatorv1.IngressController, ingressConfig
 
 func isAdmitted(ic *operatorv1.IngressController) bool {
 	for _, cond := range ic.Status.Conditions {
-		if cond.Type == iov1.IngressControllerAdmittedConditionType && cond.Status == operatorv1.ConditionTrue {
+		if cond.Type == IngressControllerAdmittedConditionType && cond.Status == operatorv1.ConditionTrue {
 			return true
 		}
 	}
@@ -316,6 +322,8 @@ func setDefaultPublishingStrategy(ic *operatorv1.IngressController, infraConfig
 				Scope: operatorv1.ExternalLoadBalancer,
 			}
 		}
+	case operatorv1.NodePortServiceStrategyType:
+		// No parameters.
 	case operatorv1.HostNetworkStrategyType:
 		// No parameters.
 	case operatorv1.PrivateStrategyType:
@@ -595,6 +603,10 @@ func (r *reconciler) ensureIngressController(ci *operatorv1.IngressController, d
 		}
 	}
 
+	if _, _, err := r.ensureNodePortService(ci, deploymentRef); err != nil {
+		errs = append(errs, err)
+	}
+
 	if internalSvc, err := r.ensureInternalIngressControllerService(ci, deploymentRef); err != nil {
 		errs = append(errs, fmt.Errorf("failed to create internal router service for ingresscontroller %s: %v", ci.Name, err))
 	} else if err := r.ensureMetricsIntegration(ci, internalSvc, deploymentRef); err != nil {
